#[non_exhaustive]#[repr(i32)]pub enum CoinRegulatedState {
Unknown = 0,
Regulated = 1,
Unregulated = 2,
}Expand description
Indicates the state of the regulation of the coin.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unknown = 0
Indicates the regulation state of the coin is unknown.
This is set when a coin has not been migrated to the
coin registry and has no 0x2::coin::RegulatedCoinMetadata
object.
Regulated = 1
Indicates a coin is regulated. RegulatedCoinMetadata will be populated.
Unregulated = 2
Indicates a coin is unregulated.
Implementations
Sourceimpl CoinRegulatedState
impl CoinRegulatedState
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of CoinRegulatedState.
Sourcepub fn from_i32(value: i32) -> Option<CoinRegulatedState>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<CoinRegulatedState>
Use the TryFrom<i32> implementation instead
Converts an i32 to a CoinRegulatedState, or None if value is not a valid variant.
Sourceimpl CoinRegulatedState
impl CoinRegulatedState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.